@@ -498,6 +498,28 @@ Re-sync domain time from domain's RTC.
 
 =back
 
+
+=item $dom->set_user_password($username, $password, $flags=0);
+
+Update the password for account C<$username> to be
+C<$password>. C<$password> is the clear-text password
+string unless the PASSWORD_ENCRYPTED flag is set.
+
+=over 4
+
+=item C<Sys::Virt::Domain::PASSWORD_ENCRYPTED>
+
+The C<$password> is encrypted with the password scheme required
+by the guest OS.
+
+=back
+
+=item $dom->rename($newname, $flags=0)
+
+Change the name of an inactive guest to be C<$newname>.
+The C<$flags> parameter is currently unused and defaults
+to zero.
+
 =item my @errs = $dom->get_disk_errors($flags=0)
 
 Returns a list of all disk errors that have occurred on
@@ -961,6 +983,13 @@ host, thus use of an explicit restricted listen address is recommended.
 
 =back
 
+=item C<Sys::Virt::Domain::MIGRATE_PARAM_MIGRATE_DISKS>
+
+The list of disks to migrate when doing block storage migration.
+In constrast to other parameters whose values are plain strings,
+the parameter value should be an array reference, whose elements
+are in turn strings representing the disk target names.
+
 =item $ddom = $dom->migrate(destcon, flags=0, dname=undef, uri=undef, bandwidth=0)
 
 Migrate a domain to an alternative host. Use of positional parameters
@@ -1028,9 +1057,9 @@ sub migrate2 {
 }
 
 
-=item $ddom = $dom->migrate_to_uri(destcon, \%params, flags=0)
+=item $ddom = $dom->migrate_to_uri(desturi, \%params, flags=0)
 
-Migrate a domain to an alternative host. The C<destri> parameter
+Migrate a domain to an alternative host. The C<desturi> parameter
 should be a valid libvirt connection URI for the remote target host.
 The C<flags> parameter takes one or more of the C<Sys::Virt::Domain::MIGRATE_XXX>
 constants described later in this document. The C<%params> parameter is
@@ -2497,6 +2526,10 @@ The peak inbound bandwidth
 
 The burstable inbound bandwidth
 
+=item Sys::Virt::Domain::BANDWIDTH_IN_FLOOR
+
+The minimum inbound bandwidth
+
 =item Sys::Virt::Domain::BANDWIDTH_OUT_AVERAGE
 
 The average outbound bandwidth
@@ -2563,6 +2596,10 @@ The defined configuration is newly added
 
 The defined configuration is an update to an existing configuration
 
+=item Sys::Virt::Domain::EVENT_DEFINED_RENAMED
+
+The defined configuration is a rename of an existing configuration
+
 =back
 
 =item Sys::Virt::Domain::EVENT_RESUMED
@@ -2713,6 +2750,10 @@ The persistent configuration has gone away
 The domain configuration has gone away due to it being
 removed by administrator.
 
+=item Sys::Virt::Domain::EVENT_UNDEFINED_RENAMED
+
+The undefined configuration is a rename of an existing configuration
+
 =back
 
 =item Sys::Virt::Domain::EVENT_PMSUSPENDED
@@ -2920,6 +2961,10 @@ The guest attempted to gracefully shutdown after the watchdog fired
 
 No action was taken, the watchdog was logged
 
+=item Sys::Virt::Domain::EVENT_WATCHDOG_INJECTNMI
+
+An NMI was injected into the guest after the watchdog fired
+
 =back
 
 =head2 GRAPHICS EVENT PHASE CONSTANTS
